// ----------------------------------------------------------------------------------
// Microsoft Developer & Platform Evangelism
// 
// Copyright (c) Microsoft Corporation. All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
// ----------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
// ----------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Microsoft.Data.Caching;

namespace WebApplication1
{
    public partial class _Default : System.Web.UI.Page
    {
        DataCache _cache;

        protected override void OnInit(EventArgs e)
        {
            // If you used the default settings for "Velocity" when you installed
            // it, the below configuration will work just fine. Otherwise, you'll
            // need to change some of the settings yourself.
            var factory = new DataCacheFactory(new DataCacheServerEndpoint[]
                                               {
                                                   new DataCacheServerEndpoint("localhost", 22233, "DistributedCacheService")
                                               },
                                               true,
                                               false);

            // Modify the name of the cache based on
            // what you called it.
            var cache1 = factory.GetDefaultCache();
            _cache = factory.GetCache("Test1");
            _cache = cache1;

            cacheButton.Click += cacheButton_Click;
            removeButton.Click += removeButton_Click;
            retreiveButton.Click += retreiveButton_Click;

            base.OnInit(e);
        }

        void removeButton_Click(object sender, EventArgs e)
        {
            var key = removeKeyTextBox.Text;
            var region = removeRegionTextBox.Text;

            if (region != String.Empty)
            {
                _cache.Remove(key, region);
            }
            else
            {
                _cache.Remove(key);
            }
        }

        void retreiveButton_Click(object sender, EventArgs e)
        {
            IEnumerable<Person> people = null;
            var key = getKeyTextBox.Text;
            var region = getRegionTextBox.Text;

            if (region != String.Empty)
            {
                people = (from person in _cache.GetObjectsByTag(new DataCacheTag(getIsVipCheckBox.Checked ? "VIP" : ""), region)
                          select person.Value).Cast<Person>();
            }
            else
            {
                var person = _cache.Get(key) as Person;

                if (person != null)
                    people = new Person[] { person };
            }

            personDetailsView.DataSource = people;
            personDetailsView.DataBind();
        }

        void cacheButton_Click(object sender, EventArgs e)
        {
            var key = keyTextBox.Text;
            var region = regionTextBox.Text;
            var person = new Person { FirstName = firstNameTextBox.Text, LastName = lastNameTextBox.Text };
            var timeout = TimeSpan.FromSeconds(Int32.Parse(ttlTextBox.Text));

            if (region != String.Empty)
            {
                try
                {
                    _cache.CreateRegion(region, false);
                }
                catch { }

                var tags = new List<DataCacheTag>();

                if (isVipCheckBox.Checked)
                {
                    tags.Add(new DataCacheTag("VIP"));
                }
                else
                {
                    tags.Add(new DataCacheTag(string.Empty));
                }

                _cache.Put(key,
                           person,
                           timeout,
                           tags,
                           region);
            }
            else
            {
                _cache.Put(key,
                           person,
                           timeout);
            }

            keyTextBox.Text = String.Empty;
            firstNameTextBox.Text = String.Empty;
            lastNameTextBox.Text = String.Empty;
            isVipCheckBox.Checked = false;
        }
    }
}